@@ -212,10 +212,6 @@ signal_analysis <- function(data,
   }
   methods <- match.arg(methods, all_methods, several.ok = TRUE)
   
-  # ===========================================================================
-  # Data Preparation
-  # ===========================================================================
-  
   if (verbose) message("=== SignalY: Comprehensive Signal Analysis ===\n")
   if (verbose) message("[1/7] Preparing data...")
   
@@ -288,10 +284,6 @@ signal_analysis <- function(data,
     X_sds <- rep(1, p)
   }
   
-  # ===========================================================================
-  # Initialize Results
-  # ===========================================================================
-  
   results <- list(
     call = call,
     data = list(
@@ -327,10 +319,6 @@ signal_analysis <- function(data,
     )
   )
   
-  # ===========================================================================
-  # Spectral Decomposition (Filters)
-  # ===========================================================================
-  
   filter_methods <- intersect(methods, c("wavelet", "emd", "hpgc"))
   
   if (length(filter_methods) > 0) {
@@ -398,10 +386,6 @@ signal_analysis <- function(data,
     }
   }
   
-  # ===========================================================================
-  # Bayesian Variable Selection (Horseshoe)
-  # ===========================================================================
-  
   if ("horseshoe" %in% methods) {
     if (verbose) message("\n[3/7] Fitting regularized Horseshoe regression...")
     
@@ -444,10 +428,6 @@ signal_analysis <- function(data,
     })
   }
   
-  # ===========================================================================
-  # PCA with Bootstrap
-  # ===========================================================================
-  
   if ("pca" %in% methods) {
     if (verbose) message("\n[4/7] Principal Component Analysis with bootstrap...")
     
@@ -482,10 +462,6 @@ signal_analysis <- function(data,
     })
   }
   
-  # ===========================================================================
-  # Dynamic Factor Model
-  # ===========================================================================
-  
   if ("dfm" %in% methods) {
     if (verbose) message("\n[5/7] Estimating Dynamic Factor Model...")
     
@@ -518,10 +494,6 @@ signal_analysis <- function(data,
     })
   }
   
-  # ===========================================================================
-  # Unit Root Tests
-  # ===========================================================================
-  
   if ("unitroot" %in% methods) {
     if (verbose) message("\n[6/7] Testing for unit roots...")
     
@@ -540,18 +512,10 @@ signal_analysis <- function(data,
     })
   }
   
-  # ===========================================================================
-  # Automated Technical Interpretation
-  # ===========================================================================
-  
   if (verbose) message("\n[7/7] Generating technical interpretation...")
   
   results$interpretation <- generate_interpretation(results, verbose = verbose)
   
-  # ===========================================================================
-  # Finalize
-  # ===========================================================================
-  
   class(results) <- "signal_analysis"
   
   if (verbose) {
@@ -579,10 +543,6 @@ generate_interpretation <- function(results, verbose = FALSE) {
     overall_summary = NULL
   )
   
-  # ---------------------------------------------------------------------------
-  # Signal Characteristics (from filters)
-  # ---------------------------------------------------------------------------
-  
   if (!is.null(results$filters)) {
     Y <- results$data$Y_std
     n <- length(Y)
@@ -613,14 +573,9 @@ generate_interpretation <- function(results, verbose = FALSE) {
     }
   }
   
-  # ---------------------------------------------------------------------------
-  # Variable Selection (from Horseshoe)
-  # ---------------------------------------------------------------------------
-  
   if (!is.null(results$horseshoe)) {
     hs <- results$horseshoe
     
-    # Usar la estructura correcta: $coefficients y $sparsity
     kappa_mean <- hs$coefficients$kappa_mean
     n_selected <- length(hs$selection$selected)
     sparsity_ratio <- 1 - n_selected / results$data$p
@@ -637,20 +592,15 @@ generate_interpretation <- function(results, verbose = FALSE) {
     else if (sparsity_ratio > 0.3) "Moderately dense"
     else "Dense: many predictors contribute"
     
-    # Usar $coefficients$mean en lugar de $summary$beta_mean
-    beta_abs <- abs(hs$coefficients$mean)
+    beta_abs <- abs(hs$coefficients$beta_mean)
     top_idx <- order(beta_abs, decreasing = TRUE)[1:min(5, length(beta_abs))]
     interpretation$variable_selection$top_predictors <- data.frame(
       variable = hs$coefficients$variable[top_idx],
-      beta = hs$coefficients$mean[top_idx],
+      beta = hs$coefficients$beta_mean[top_idx],
       kappa = kappa_mean[top_idx]
     )
   }
   
-  # ---------------------------------------------------------------------------
-  # Factor Structure (from PCA/DFM)
-  # ---------------------------------------------------------------------------
-  
   if (!is.null(results$pca)) {
     pca <- results$pca
     
@@ -685,10 +635,6 @@ generate_interpretation <- function(results, verbose = FALSE) {
       sum(results$dfm$variance_explained)
   }
   
-  # ---------------------------------------------------------------------------
-  # Persistence Properties (from Unit Root)
-  # ---------------------------------------------------------------------------
-  
   if (!is.null(results$unitroot)) {
     ur <- results$unitroot
     
@@ -721,10 +667,6 @@ generate_interpretation <- function(results, verbose = FALSE) {
     )
   }
   
-  # ---------------------------------------------------------------------------
-  # Overall Summary
-  # ---------------------------------------------------------------------------
-  
   summary_parts <- c()
   
   if (!is.null(interpretation$signal_characteristics$smoothness_interpretation)) {
@@ -760,11 +702,6 @@ generate_interpretation <- function(results, verbose = FALSE) {
   return(interpretation)
 }
 
-
-# =============================================================================
-# S3 Methods: print, summary, plot
-# =============================================================================
-
 #' @title Print Method for signal_analysis Objects
 #' @description Print a concise summary of signal analysis results.
 #' @param x An object of class \code{signal_analysis}
@@ -777,7 +714,6 @@ print.signal_analysis <- function(x, ...) {
   cat("                    SignalY: Signal Analysis Results                        \n")
   cat("===========================================================================\n\n")
   
-  # Data summary
   cat("DATA SUMMARY\n")
   cat("-----------------------------------------------------------------------------\n")
   cat("  Observations:", x$data$n, "\n")
@@ -785,17 +721,14 @@ print.signal_analysis <- function(x, ...) {
   cat("  Methods:     ", paste(x$config$methods, collapse = ", "), "\n")
   cat("\n")
   
-  # Interpretation
   if (!is.null(x$interpretation$overall_summary) && 
       nchar(x$interpretation$overall_summary) > 0) {
     cat("SYNTHESIS\n")
     cat("-----------------------------------------------------------------------------\n")
-    # Word wrap the summary
     summary_wrapped <- strwrap(x$interpretation$overall_summary, width = 75)
     cat(" ", paste(summary_wrapped, collapse = "\n  "), "\n\n")
   }
   
-  # Key metrics
   cat("KEY METRICS\n")
   cat("-----------------------------------------------------------------------------\n")
   
@@ -851,10 +784,6 @@ summary.signal_analysis <- function(object, ...) {
   cat("|               SignalY: Detailed Signal Analysis Summary                   |\n")
   cat("+===========================================================================+\n\n")
   
-  # ===========================================================================
-  # 1. Data Overview
-  # ===========================================================================
-  
   cat("+-----------------------------------------------------------------------------+\n")
   cat("| 1. DATA OVERVIEW                                                           |\n")
   cat("+-----------------------------------------------------------------------------+\n\n")
@@ -865,10 +794,6 @@ summary.signal_analysis <- function(object, ...) {
   cat("  First-differenced:", object$config$first_difference, "\n")
   cat("  NA handling:", object$config$na_action, "\n\n")
   
-  # ===========================================================================
-  # 2. Spectral Decomposition
-  # ===========================================================================
-  
   if (!is.null(object$filters)) {
     cat("+-----------------------------------------------------------------------------+\n")
     cat("| 2. SPECTRAL DECOMPOSITION                                                  |\n")
@@ -877,11 +802,9 @@ summary.signal_analysis <- function(object, ...) {
     if (!is.null(object$filters$wavelet)) {
       cat("  WAVELET MULTI-RESOLUTION ANALYSIS\n")
       cat("  -------------------------------------\n")
-      # CORREGIDO: Fallback robusto para el nombre del filtro
       wf_name <- object$filters$wavelet$filter %||% object$config$filter_config$wavelet_filter %||% "N/A"
       cat("  Filter:", wf_name, "\n")
       cat("  Levels combined:", paste(object$filters$wavelet$levels, collapse = ", "), "\n")
-      # Robusto para combined signal variance
       comb_var <- tryCatch(var(object$filters$wavelet$combined), error = function(e) NA)
       cat("  Combined signal variance:", 
           if (!is.na(comb_var)) round(comb_var, 4) else "N/A", "\n\n")
@@ -909,7 +832,6 @@ summary.signal_analysis <- function(object, ...) {
       cat("\n")
     }
     
-    # Signal characteristics
     if (!is.null(object$interpretation$signal_characteristics)) {
       sc <- object$interpretation$signal_characteristics
       cat("  SIGNAL CHARACTERISTICS\n")
@@ -926,10 +848,6 @@ summary.signal_analysis <- function(object, ...) {
     }
   }
   
-  # ===========================================================================
-  # 3. Horseshoe Regression
-  # ===========================================================================
-  
   if (!is.null(object$horseshoe)) {
     cat("+-----------------------------------------------------------------------------+\n")
     cat("| 3. REGULARIZED HORSESHOE REGRESSION                                        |\n")
@@ -940,7 +858,6 @@ summary.signal_analysis <- function(object, ...) {
     cat("  MCMC DIAGNOSTICS\n")
     cat("  -------------------------------------\n")
     if (!is.null(hs$diagnostics)) {
-      # Acceso robusto a diagnósticos
       n_div <- hs$diagnostics$n_divergences
       rhat <- hs$diagnostics$rhat_max
       ess_bulk <- hs$diagnostics$ess_bulk_min
@@ -955,8 +872,6 @@ summary.signal_analysis <- function(object, ...) {
     
     cat("  SHRINKAGE SUMMARY\n")
     cat("  -------------------------------------\n")
-    # Usar la estructura correcta: $hyperparameters es un data frame
-    # Acceso robusto a tau
     tau_val <- NA
     if (!is.null(hs$hyperparameters) && is.data.frame(hs$hyperparameters)) {
       tau_row <- hs$hyperparameters[hs$hyperparameters$parameter == "tau", ]
@@ -970,7 +885,6 @@ summary.signal_analysis <- function(object, ...) {
       cat("  Global tau (mean): N/A\n")
     }
     
-    # Acceso robusto a m_eff
     m_eff_val <- if (!is.null(hs$sparsity$m_eff_mean) && is.numeric(hs$sparsity$m_eff_mean)) {
       hs$sparsity$m_eff_mean
     } else NA
@@ -1010,7 +924,6 @@ summary.signal_analysis <- function(object, ...) {
       cat("  MODEL FIT (LOO-CV)\n")
       cat("  -------------------------------------\n")
       
-      # Acceso robusto a las estimaciones de LOO
       elpd_est <- tryCatch(hs$loo$estimates["elpd_loo", "Estimate"], error = function(e) NA)
       elpd_se <- tryCatch(hs$loo$estimates["elpd_loo", "SE"], error = function(e) NA)
       looic <- tryCatch(hs$loo$estimates["looic", "Estimate"], error = function(e) NA)
@@ -1028,10 +941,6 @@ summary.signal_analysis <- function(object, ...) {
     }
   }
   
-  # ===========================================================================
-  # 4. PCA
-  # ===========================================================================
-  
   if (!is.null(object$pca)) {
     cat("+-----------------------------------------------------------------------------+\n")
     cat("| 4. PRINCIPAL COMPONENT ANALYSIS                                            |\n")
@@ -1092,10 +1001,6 @@ summary.signal_analysis <- function(object, ...) {
     }
   }
   
-  # ===========================================================================
-  # 5. Dynamic Factor Model
-  # ===========================================================================
-  
   if (!is.null(object$dfm)) {
     cat("+-----------------------------------------------------------------------------+\n")
     cat("| 5. DYNAMIC FACTOR MODEL                                                    |\n")
@@ -1105,11 +1010,9 @@ summary.signal_analysis <- function(object, ...) {
     
     cat("  FACTOR SELECTION\n")
     cat("  -------------------------------------\n")
-    # CORREGIDO: usar ic en lugar de ic_criterion
     cat("  Information criterion:", object$config$dfm_config$ic %||% "bai_ng_2", "\n")
     cat("  Optimal factors:", if (!is.null(dfm$n_factors)) dfm$n_factors else "N/A", "\n")
     
-    # Acceso robusto a variance_explained
     var_expl <- if (!is.null(dfm$variance_explained) && is.numeric(dfm$variance_explained) && length(dfm$variance_explained) > 0) {
       round(sum(dfm$variance_explained) * 100, 1)
     } else "N/A"
@@ -1127,10 +1030,6 @@ summary.signal_analysis <- function(object, ...) {
     }
   }
   
-  # ===========================================================================
-  # 6. Unit Root Tests
-  # ===========================================================================
-  
   if (!is.null(object$unitroot)) {
     cat("+-----------------------------------------------------------------------------+\n")
     cat("| 6. UNIT ROOT TESTS                                                         |\n")
@@ -1147,7 +1046,6 @@ summary.signal_analysis <- function(object, ...) {
     cat("  TEST RESULTS SUMMARY\n")
     cat("  -------------------------------------\n")
     
-    # Print summary table of tests
     if (!is.null(ur$tests) && length(ur$tests) > 0) {
       for (test_name in names(ur$tests)) {
         test <- ur$tests[[test_name]]
@@ -1163,10 +1061,6 @@ summary.signal_analysis <- function(object, ...) {
     cat("\n")
   }
   
-  # ===========================================================================
-  # 7. Overall Summary
-  # ===========================================================================
-  
   cat("+-----------------------------------------------------------------------------+\n")
   cat("| 7. OVERALL SYNTHESIS                                                        |\n")
   cat("+-----------------------------------------------------------------------------+\n\n")
@@ -1194,18 +1088,15 @@ summary.signal_analysis <- function(object, ...) {
 #' @export
 plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
   
-  # Determine if interactive
   if (is.null(ask)) {
     ask <- interactive() && length(which) > 1
   }
   
-  # Expand "all"
   all_plots <- c("filters", "horseshoe", "pca", "dfm")
   if ("all" %in% which) {
     which <- all_plots
   }
   
-  # Set up plotting
   if (ask) {
     oask <- grDevices::devAskNewPage(TRUE)
     on.exit(grDevices::devAskNewPage(oask))
@@ -1214,26 +1105,19 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
   old_par <- graphics::par(no.readonly = TRUE)
   on.exit(graphics::par(old_par), add = TRUE)
   
-  # ===========================================================================
-  # Filter Plots
-  # ===========================================================================
-  
   if ("filters" %in% which && !is.null(x$filters)) {
     
-    # Time series and decomposition
     graphics::par(mfrow = c(3, 1), mar = c(4, 4, 3, 2))
     
     Y <- x$data$Y_std
     n <- length(Y)
     time_idx <- 1:n
     
-    # Original series
     graphics::plot(time_idx, Y, type = "l", col = "black", lwd = 1.5,
                    main = "Original Series (Standardized)",
                    xlab = "Time", ylab = "Y")
     graphics::grid()
     
-    # HP-GC decomposition if available
     if (!is.null(x$filters$hpgc)) {
       graphics::plot(time_idx, Y, type = "l", col = "gray60", lwd = 1,
                      main = "HP-GC Trend-Cycle Decomposition",
@@ -1249,7 +1133,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
       graphics::abline(h = 0, lty = 2, col = "gray40")
       graphics::grid()
     } else if (!is.null(x$filters$wavelet)) {
-      # Wavelet combined signal
       graphics::plot(time_idx, x$filters$wavelet$combined, type = "l", 
                      col = "darkgreen", lwd = 1.5,
                      main = paste("Wavelet Combined Signal (D", 
@@ -1257,7 +1140,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
                      xlab = "Time", ylab = "Combined")
       graphics::grid()
       
-      # Smooth component
       graphics::plot(time_idx, x$filters$wavelet$smooth, type = "l",
                      col = "purple", lwd = 1.5,
                      main = "Wavelet Smooth Component",
@@ -1265,7 +1147,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
       graphics::grid()
     }
     
-    # EMD if available
     if (!is.null(x$filters$emd) && x$filters$emd$n_imf >= 2) {
       graphics::par(mfrow = c(min(4, x$filters$emd$n_imf + 1), 1), 
                     mar = c(3, 4, 2, 2))
@@ -1281,10 +1162,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
     }
   }
   
-  # ===========================================================================
-  # Horseshoe Plots
-  # ===========================================================================
-  
   if ("horseshoe" %in% which && !is.null(x$horseshoe)) {
     
     hs <- x$horseshoe
@@ -1294,21 +1171,16 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
     
     graphics::par(mfrow = c(2, 2), mar = c(5, 6, 4, 2))
     
-    # Usar la estructura correcta: $coefficients es un data frame
-    # Nota: coefficients está ordenado por relevance_score, necesitamos reordenar
     coef_df <- hs$coefficients
     
-    # Crear vectores con el orden original de variables
-    beta_mean <- coef_df$mean
-    beta_lower <- coef_df$q025
-    beta_upper <- coef_df$q975
+    beta_mean <- coef_df$beta_mean
+    beta_lower <- coef_df$beta_q025
+    beta_upper <- coef_df$beta_q975
     kappa_mean <- coef_df$kappa_mean
     coef_var_names <- coef_df$variable
     
-    # Determinar cuáles están seleccionados (es un vector de nombres)
     is_selected <- coef_var_names %in% hs$selection$selected
     
-    # Ordenar por |beta| para el plot
     ord <- order(abs(beta_mean), decreasing = TRUE)
     top_n <- min(20, length(beta_mean))
     ord <- ord[1:top_n]
@@ -1325,7 +1197,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
     graphics::abline(v = 0, lty = 2, col = "red")
     graphics::axis(2, at = y_pos, labels = coef_var_names[ord], las = 1, cex.axis = 0.7)
     
-    # Shrinkage factors (kappa)
     graphics::barplot(kappa_mean[ord], horiz = TRUE, names.arg = coef_var_names[ord],
                       col = ifelse(kappa_mean[ord] < hs$selection$threshold, 
                                    "steelblue", "gray70"),
@@ -1333,7 +1204,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
                       xlab = expression(kappa), las = 1, cex.names = 0.7)
     graphics::abline(v = hs$selection$threshold, lty = 2, col = "red", lwd = 2)
     
-    # Kappa vs |beta|
     graphics::plot(kappa_mean, abs(beta_mean), pch = 19,
                    col = ifelse(is_selected, "blue", "gray60"),
                    main = expression("Shrinkage vs |"*beta*"|"),
@@ -1341,7 +1211,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
     graphics::abline(v = hs$selection$threshold, lty = 2, col = "red")
     graphics::grid()
     
-    # Posterior predictive check
     if (!is.null(hs$ppc) && !is.null(hs$ppc$y_rep_mean)) {
       y_rep_mean <- hs$ppc$y_rep_mean
       y_obs <- x$data$Y_std
@@ -1354,10 +1223,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
     }
   }
   
-  # ===========================================================================
-  # PCA Plots
-  # ===========================================================================
-  
   if ("pca" %in% which && !is.null(x$pca)) {
     
     pca <- x$pca
@@ -1367,7 +1232,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
     
     graphics::par(mfrow = c(2, 2), mar = c(5, 4, 4, 2))
     
-    # Scree plot
     n_show <- min(10, length(pca$variance_explained))
     ve <- pca$variance_explained[1:n_show]
     
@@ -1379,7 +1243,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
     graphics::lines(1:n_show - 0.5, cumsum(ve) * 100, type = "b", pch = 19, col = "red")
     graphics::axis(4, at = pretty(cumsum(ve) * 100), col.axis = "red")
     
-    # PC1 loadings
     loadings_pc1 <- pca$loadings[, 1]
     ord <- order(abs(loadings_pc1), decreasing = TRUE)
     top_n <- min(20, p)
@@ -1391,7 +1254,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
                       xlab = "Loading", las = 1, cex.names = 0.7)
     graphics::abline(v = 0, lty = 2)
     
-    # PC1 vs PC2 scores
     if (pca$n_components >= 2) {
       graphics::plot(pca$scores[, 1], pca$scores[, 2], pch = 19, col = "steelblue",
                      main = "Score Plot (PC1 vs PC2)",
@@ -1400,7 +1262,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
       graphics::grid()
     }
     
-    # Entropy by component
     n_ent <- min(5, length(pca$entropy))
     graphics::barplot(pca$entropy[1:n_ent], names.arg = paste0("PC", 1:n_ent),
                       col = "darkgreen",
@@ -1410,10 +1271,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
     graphics::text(n_ent, log(p), "Max entropy", pos = 1, col = "red", cex = 0.8)
   }
   
-  # ===========================================================================
-  # DFM Plots
-  # ===========================================================================
-  
   if ("dfm" %in% which && !is.null(x$dfm)) {
     
     dfm <- x$dfm
@@ -1422,7 +1279,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
     
     graphics::par(mfrow = c(2, 2), mar = c(4, 4, 3, 2))
     
-    # Information criterion
     if (!is.null(dfm$ic_values)) {
       n_ic <- length(dfm$ic_values)
       graphics::plot(1:n_ic, dfm$ic_values, type = "b", pch = 19,
@@ -1434,7 +1290,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
       graphics::grid()
     }
     
-    # Factor time series
     if (!is.null(dfm$factors)) {
       n_plot <- min(3, ncol(dfm$factors))
       for (i in 1:n_plot) {
@@ -1446,7 +1301,6 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
       }
     }
     
-    # Variance explained
     if (!is.null(dfm$variance_explained)) {
       n_show <- length(dfm$variance_explained)
       graphics::barplot(dfm$variance_explained * 100, 
@@ -1457,17 +1311,11 @@ plot.signal_analysis <- function(x, which = "all", ask = NULL, ...) {
     }
   }
   
-  # Reset par
   graphics::par(mfrow = c(1, 1))
   
   invisible(x)
 }
 
-
-# =============================================================================
-# Helper: Null-coalescing operator
-# =============================================================================
-
 `%||%` <- function(a, b) if (is.null(a)) b else a
 
 #' @title Interactive Plot for Signal Analysis
